@@ -29,7 +29,8 @@ NUMBERS_PATTERN = re.compile('(?<=\d),(?=\d)')
 
 
 def smart_truncate(string, max_length=0, word_boundaries=False, separator=' ', save_order=False):
-    """Truncate a string.
+    """
+    Truncate a string.
     :param string (str): string for modification
     :param max_length (int): output string length
     :param word_boundaries (bool):
@@ -71,7 +72,8 @@ def smart_truncate(string, max_length=0, word_boundaries=False, separator=' ', s
 
 def slugify(text, entities=True, decimal=True, hexadecimal=True, max_length=0, word_boundary=False,
             separator='-', save_order=False, stopwords=()):
-    """Make a slug from the given text.
+    """
+    Make a slug from the given text.
     :param text (str): initial text
     :param entities (bool):
     :param decimal (bool):
@@ -88,6 +90,9 @@ def slugify(text, entities=True, decimal=True, hexadecimal=True, max_length=0, w
     if not isinstance(text, _unicode_type):
         text = _unicode(text, 'utf-8', 'ignore')
 
+    # replace quotes with dashes - pre-process
+    text = QUOTE_PATTERN.sub('-', text)
+
     # decode unicode
     text = unidecode.unidecode(text)
 
@@ -118,10 +123,15 @@ def slugify(text, entities=True, decimal=True, hexadecimal=True, max_length=0, w
     if sys.version_info < (3,):
         text = text.encode('ascii', 'ignore')
 
+    # make the text lowercase
+    text = text.lower()
+
+    # remove generated quotes -- post-process
+    text = QUOTE_PATTERN.sub('', text)
+
     # replace unwanted characters
-    text = QUOTE_PATTERN.sub('', text.lower())  # replace ' with nothing instead with -
-    text = NUMBERS_PATTERN.sub('', text.lower())
-    text = ALLOWED_CHARS_PATTERN.sub('-', text.lower())
+    text = NUMBERS_PATTERN.sub('', text)
+    text = ALLOWED_CHARS_PATTERN.sub('-', text)
 
     # remove redundant -
     text = DUPLICATE_DASH_PATTERN.sub('-', text).strip('-')
@@ -129,8 +139,8 @@ def slugify(text, entities=True, decimal=True, hexadecimal=True, max_length=0, w
     # remove stopwords
     if stopwords:
         stopwords_lower = [s.lower() for s in stopwords]
-        words = [w for w in text.split(separator) if w not in stopwords_lower]
-        text = separator.join(words)
+        words = [w for w in text.split('-') if w not in stopwords_lower]
+        text = '-'.join(words)
 
     # smart truncate if requested
     if max_length > 0:
